@@ -65,7 +65,7 @@ def setup_virtualenv():
       error('failed to create virtualenv.')
 
     result = run("""
-      . %(virtualenv)s/bin/activate && pip install %(pybundle_path)s
+      . %(virtualenv)s/bin/activate && pip install --upgrade %(pybundle_path)s
     """ % var('virtualenv', 'pybundle_path'))
     if result.failed:
       error('failed to install pybundle.')
@@ -78,7 +78,7 @@ def setup_pybundle():
     requirement = 'packages.txt'
     result = local("""
       if test -f %(requirement)s; then pip install --requirement=%(requirement)s; else pip freeze --local > %(requirement)s; fi &&
-      if test %(application)s.pybundle -ot %(requirement)s; then
+      if test \! -f %(application)s.pybundle -o %(application)s.pybundle -ot %(requirement)s; then
         pip bundle --requirement=%(requirement)s %(application)s.pybundle;
       fi
     """ % var('application', requirement=requirement))
